==> immutable-recursive-0.0.1.tgz: package/src/__tests__/utils-test.js <==
import tape from 'tape';
import {
  is,
  fromJS,
  Iterable,
  List,
  Map,
  OrderedMap
} from 'immutable';

import {
	asList,
  isLeaf,
  keysToPath,
  keysToPathChildren
} from '../utils';

import {
  deepGet
} from '../get';

tape('asList', test => {
    test.plan(3);

    test.ok(is(
    	asList(fromJS(["a","b"])),
    	fromJS(["a","b"])
    ), 'passes through Lists with no change');

    test.ok(is(
    	asList(["a","b"]),
    	fromJS(["a","b"])
    ), 'converts arrays to Lists');

    test.ok(is(
    	asList(null),
    	List()
    ), 'converts null to an empty List');
});

tape('isLeaf', test => {
    
    const nestedMaps = fromJS({
      a: {
        b: "B",
        c: "C",
        d: {
          e: "E"
        }
      },
      f: "F"
    });
    
    const nestedLists = fromJS([
      ["A","B","C"],
      ["D",["E","F"]],
      "G"
    ]);
    
    const nodesWithChildCollections = fromJS({
      name: "root",
      children: [
        {
          name: "child 1",
          children: [
            {name: "grandchild 1"},
            {name: "grandchild 2"}
          ]
        },
        {
          name: "child 2",
          children: []
        },
        {name: "child 3"}
      ]
    });

    test.plan(7);

    test.notOk(isLeaf(nestedMaps.get('a')), 'is false if node is a map');
    test.ok(isLeaf(nestedMaps.getIn(['a','b'])), 'is true if node is not a map');

    test.notOk(isLeaf(nestedLists.getIn([1,1])), 'is false if node is a list');
    test.ok(isLeaf(nestedLists.get(2)), 'is true if node is not a list');

    const nodeChild1 = deepGet([0], ['children'])(nodesWithChildCollections);
    const nodeChild2 = deepGet([1], ['children'])(nodesWithChildCollections);
    const nodeChild3 = deepGet([2], ['children'])(nodesWithChildCollections);

    test.notOk(isLeaf(nodeChild1, ['children']), 'is false if node has a child iterable');
    test.ok(isLeaf(nodeChild3, ['children']), 'is true if node has no child iterable');
    test.ok(isLeaf(nodeChild2, ['children']), 'is true if node has empty child iterable');
});

tape('keysToPath', test => {
    test.plan(5);

    test.ok(is(
      keysToPath([0,1]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is not set');

    test.ok(is(
      keysToPath([0,1],[]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is empty array');

    test.ok(is(
      keysToPath([0],['children']),
      fromJS(['children',0])
    ), 'path is simply childPath with key appended if only one key');

    test.ok(is(
      keysToPath([0,2,4],['children']),
      fromJS(['children',0,'children',2,'children',4])
    ), 'path adds childPath before every key in keys');

    test.ok(is(
      keysToPath([0,1],['data','children']),
      fromJS(['data','children',0,'data','children',1])
    ), 'can cope with childPaths longer than one');
});

tape('keysToPathChildren', test => {
    test.plan(5);

    test.ok(is(
      keysToPathChildren([0,1]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is not set');

    test.ok(is(
      keysToPathChildren([0,1],[]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is empty array');

    test.ok(is(
      keysToPathChildren([],['children']),
      fromJS(['children'])
    ), 'path is simply childPath if no keys given');

    test.ok(is(
      keysToPathChildren([0,2,4],['children']),
      fromJS(['children',0,'children',2,'children',4,'children'])
    ), 'path adds childPath before every key in keys + 1');

    test.ok(is(
      keysToPathChildren([0,1],['data','children']),
      fromJS(['data','children',0,'data','children',1,'data','children'])
    ), 'can cope with childPaths longer than one');
});

==> immutable-recursive-0.0.4.tgz: package/src/__tests__/utils-test.js <==
import tape from 'tape';
import {
  is,
  fromJS,
  Iterable,
  List,
  Map,
  OrderedMap
} from 'immutable';

import {
	asList,
  isLeaf,
  nodePathToKeys,
  nodePathToKeysChildren
} from '../utils';

import {
  deepGet
} from '../get';

const nestedMaps = fromJS({
  a: {
    b: "B",
    c: "C",
    d: {
      e: "E"
    }
  },
  f: "F"
});

const nestedLists = fromJS([
  ["A","B","C"],
  ["D",["E","F"]],
  "G"
]);

const nodesWithChildCollections = fromJS({
  name: "root",
  children: [
    {
      name: "child 1",
      children: [
        {name: "grandchild 1"},
        {name: "grandchild 2"}
      ]
    },
    {
      name: "child 2",
      children: []
    },
    {name: "child 3"}
  ]
});

tape('asList', test => {
    test.plan(3);

    test.ok(is(
    	asList(fromJS(["a","b"])),
    	fromJS(["a","b"])
    ), 'passes through Lists with no change');

    test.ok(is(
    	asList(["a","b"]),
    	fromJS(["a","b"])
    ), 'converts arrays to Lists');

    test.ok(is(
    	asList(null),
    	List()
    ), 'converts null to an empty List');
});

tape('isLeaf', test => {
    test.plan(7);

    test.notOk(isLeaf(nestedMaps.get('a')), 'is false if node is a map');
    test.ok(isLeaf(nestedMaps.getIn(['a','b'])), 'is true if node is not a map');

    test.notOk(isLeaf(nestedLists.getIn([1,1])), 'is false if node is a list');
    test.ok(isLeaf(nestedLists.get(2)), 'is true if node is not a list');

    const nodeChild1 = deepGet([0], ['children'])(nodesWithChildCollections);
    const nodeChild2 = deepGet([1], ['children'])(nodesWithChildCollections);
    const nodeChild3 = deepGet([2], ['children'])(nodesWithChildCollections);

    test.notOk(isLeaf(nodeChild1, ['children']), 'is false if node has a child iterable');
    test.ok(isLeaf(nodeChild3, ['children']), 'is true if node has no child iterable');
    test.ok(isLeaf(nodeChild2, ['children']), 'is true if node has empty child iterable');
});

tape('nodePathToKeys', test => {
    test.plan(5);

    test.ok(is(
      nodePathToKeys([0,1]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is not set');

    test.ok(is(
      nodePathToKeys([0,1],[]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is empty array');

    test.ok(is(
      nodePathToKeys([0],['children']),
      fromJS(['children',0])
    ), 'path is simply childPath with key appended if only one key');

    test.ok(is(
      nodePathToKeys([0,2,4],['children']),
      fromJS(['children',0,'children',2,'children',4])
    ), 'path adds childPath before every key in keys');

    test.ok(is(
      nodePathToKeys([0,1],['data','children']),
      fromJS(['data','children',0,'data','children',1])
    ), 'can cope with childPaths longer than one');
});

tape('nodePathToKeysChildren', test => {
    test.plan(5);

    test.ok(is(
      nodePathToKeysChildren([0,1]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is not set');

    test.ok(is(
      nodePathToKeysChildren([0,1],[]),
      fromJS([0,1])
    ), 'path is same as keys if childPath is empty array');

    test.ok(is(
      nodePathToKeysChildren([],['children']),
      fromJS(['children'])
    ), 'path is simply childPath if no keys given');

    test.ok(is(
      nodePathToKeysChildren([0,2,4],['children']),
      fromJS(['children',0,'children',2,'children',4,'children'])
    ), 'path adds childPath before every key in keys + 1');

    test.ok(is(
      nodePathToKeysChildren([0,1],['data','children']),
      fromJS(['data','children',0,'data','children',1,'data','children'])
    ), 'can cope with childPaths longer than one');
});
